@@ -26,7 +26,14 @@ import time
 import gc
 import subprocess
 import requests
-import board
+
+try:
+    import board
+
+    DISPLAY_ARG_REQUIRED = False
+except NotImplementedError:
+    # okay to run Generic Linux
+    DISPLAY_ARG_REQUIRED = True
 import digitalio
 import displayio
 import wget as wget_lib
@@ -38,11 +45,6 @@ from PIL import Image
 import adafruit_focaltouch
 import adafruit_ili9341
 
-try:
-    from secrets import secrets  # pylint: disable=no-name-in-module
-except RuntimeError:
-    raise "API tokens are kept in secrets.py, please add them there!" from RuntimeError
-
 __version__ = "0.0.0-auto.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_pyportal.git"
 
@@ -125,6 +127,7 @@ class PyPortal:
     :param debug: Turn on debug print outs. Defaults to False.
     :param display: The displayio display object to use
     :param touchscreen: The touchscreen object to use. Usually STMPE610 or FocalTouch.
+    :param secrets: The secrets object to use. If not supplied we will attempt to import.
 
     """
 
@@ -158,9 +161,20 @@ class PyPortal:
         external_spi=None,
         debug=False,
         display=None,
-        touchscreen=None
+        touchscreen=None,
+        secrets=None
     ):
 
+        if not secrets:
+            # pylint: disable=import-outside-toplevel
+            try:
+                from secrets import secrets  # pylint: disable=no-name-in-module
+            except RuntimeError:
+                raise "API tokens are kept in secrets.py, please add them there!" from RuntimeError
+            self.secrets = secrets
+        else:
+            self.secrets = secrets
+
         self._debug = debug
         self._debug_start = time.monotonic()
         self.display = display
@@ -168,6 +182,10 @@ class PyPortal:
         spi = None
 
         if self.display is None:
+            if DISPLAY_ARG_REQUIRED:
+                raise RuntimeError(
+                    "Display must be provided on platforms without board."
+                )
             if external_spi:  # If SPI Object Passed
                 spi = external_spi
             else:  # Else: Make ESP32 connection
@@ -513,14 +531,14 @@ class PyPortal:
         # pylint: enable=line-too-long
         api_url = None
         try:
-            aio_username = secrets["aio_username"]
-            aio_key = secrets["aio_key"]
+            aio_username = self.secrets["aio_username"]
+            aio_key = self.secrets["aio_key"]
         except KeyError:
             raise KeyError(
                 "\n\nOur time service requires a login/password to rate-limit. Please register for a free adafruit.io account and place the user/key in your secrets file under 'aio_username' and 'aio_key'"  # pylint: disable=line-too-long
             ) from KeyError
 
-        location = secrets.get("timezone", location)
+        location = self.secrets.get("timezone", location)
         if location:
             print("Getting time for timezone", location)
             api_url = (TIME_SERVICE + "&tz=%s") % (aio_username, aio_key, location)
@@ -571,14 +589,13 @@ class PyPortal:
 
     # pylint: enable=no-self-use
 
-    @staticmethod
-    def image_converter_url(image_url, width, height, color_depth=16):
+    def image_converter_url(self, image_url, width, height, color_depth=16):
         """Generate a converted image url from the url passed in,
            with the given width and height. aio_username and aio_key must be
            set in secrets."""
         try:
-            aio_username = secrets["aio_username"]
-            aio_key = secrets["aio_key"]
+            aio_username = self.secrets["aio_username"]
+            aio_key = self.secrets["aio_key"]
         except KeyError:
             raise KeyError(
                 "\n\nOur image converter service require a login/password to rate-limit. Please register for a free adafruit.io account and place the user/key in your secrets file under 'aio_username' and 'aio_key'"  # pylint: disable=line-too-long
@@ -610,8 +627,8 @@ class PyPortal:
         # pylint: enable=line-too-long
 
         try:
-            aio_username = secrets["aio_username"]
-            aio_key = secrets["aio_key"]
+            aio_username = self.secrets["aio_username"]
+            aio_key = self.secrets["aio_key"]
         except KeyError:
             raise KeyError(
                 "Adafruit IO secrets are kept in secrets.py, please add them there!\n\n"
